[PoC 031/241] global: Migrate CONFIG_FLASH_SHOW_PROGRESS to CFG

Tom Rini trini at konsulko.com
Sun Nov 20 14:30:22 CET 2022


Signed-off-by: Tom Rini <trini at konsulko.com>
---
 README                               |  2 +-
 drivers/mtd/cfi_flash.c              | 14 +++++++-------
 include/configs/P1010RDB.h           |  2 +-
 include/configs/P2041RDB.h           |  2 +-
 include/configs/T102xRDB.h           |  2 +-
 include/configs/T104xRDB.h           |  2 +-
 include/configs/T208xQDS.h           |  2 +-
 include/configs/T208xRDB.h           |  2 +-
 include/configs/T4240RDB.h           |  2 +-
 include/configs/blanche.h            |  2 +-
 include/configs/draak.h              |  2 +-
 include/configs/eb_cpu5282.h         |  2 +-
 include/configs/ebisu.h              |  2 +-
 include/configs/km/pg-wcom-ls102xa.h |  2 +-
 include/configs/ls1021aqds.h         |  2 +-
 include/configs/ls1021atwr.h         |  2 +-
 include/configs/ls1043a_common.h     |  2 +-
 include/configs/ls1046aqds.h         |  2 +-
 include/configs/ls1088aqds.h         |  2 +-
 include/configs/ls1088ardb.h         |  2 +-
 include/configs/ls2080aqds.h         |  2 +-
 include/configs/ls2080ardb.h         |  2 +-
 include/configs/p1_p2_rdb_pc.h       |  2 +-
 include/configs/salvator-x.h         |  2 +-
 include/configs/ulcb.h               |  2 +-
 include/configs/zynq-common.h        |  2 +-
 scripts/config_whitelist.txt         |  2 +-
 27 files changed, 33 insertions(+), 33 deletions(-)

diff --git a/README b/README
index 52545b78a19b..ea5f4cc10659 100644
--- a/README
+++ b/README
@@ -1481,7 +1481,7 @@ Configuration Settings:
 		s29ws-n MirrorBit flash has non-standard addresses for buffered
 		write commands.
 
-- CONFIG_FLASH_SHOW_PROGRESS
+- CFG_FLASH_SHOW_PROGRESS
 		If defined (must be an integer), print out countdown
 		digits and dots.  Recommended value: 45 (9..1) for 80
 		column displays, 15 (3..1) for 40 column displays.
diff --git a/include/configs/P1010RDB.h b/include/configs/P1010RDB.h
index bc24be79366c..67ee74ba6232 100644
--- a/include/configs/P1010RDB.h
+++ b/include/configs/P1010RDB.h
@@ -161,7 +161,7 @@ extern unsigned long get_sdram_size(void);
 #define CFG_SYS_NOR_FTIM3	0x0
 
 #define CFG_SYS_FLASH_BANKS_LIST	{CFG_SYS_FLASH_BASE_PHYS}
-#define CONFIG_FLASH_SHOW_PROGRESS	45	/* count down from 45/5: 9..1 */
+#define CFG_FLASH_SHOW_PROGRESS	45	/* count down from 45/5: 9..1 */
 
 /* CFI for NOR Flash */
 
diff --git a/include/configs/P2041RDB.h b/include/configs/P2041RDB.h
index 834400f1d601..b05601489d85 100644
--- a/include/configs/P2041RDB.h
+++ b/include/configs/P2041RDB.h
@@ -101,7 +101,7 @@
 #define PIXIS_LBMAP_SHIFT	4
 #define PIXIS_LBMAP_ALTBANK	0x40
 
-#define CONFIG_FLASH_SHOW_PROGRESS	45 /* count down from 45/5: 9..1 */
+#define CFG_FLASH_SHOW_PROGRESS	45 /* count down from 45/5: 9..1 */
 
 /* Nand Flash */
 #ifdef CONFIG_NAND_FSL_ELBC
diff --git a/include/configs/T102xRDB.h b/include/configs/T102xRDB.h
index f666683bcc4b..09087a70895d 100644
--- a/include/configs/T102xRDB.h
+++ b/include/configs/T102xRDB.h
@@ -158,7 +158,7 @@
 				FTIM2_NOR_TWP(0x1c))
 #define CFG_SYS_NOR_FTIM3	0x0
 
-#define CONFIG_FLASH_SHOW_PROGRESS	45 /* count down from 45/5: 9..1 */
+#define CFG_FLASH_SHOW_PROGRESS	45 /* count down from 45/5: 9..1 */
 
 #define CFG_SYS_FLASH_BANKS_LIST	{CFG_SYS_FLASH_BASE_PHYS}
 
diff --git a/include/configs/T104xRDB.h b/include/configs/T104xRDB.h
index 53bd8e85a627..e6a9dccd752b 100644
--- a/include/configs/T104xRDB.h
+++ b/include/configs/T104xRDB.h
@@ -126,7 +126,7 @@
 				FTIM2_NOR_TWP(0x1c))
 #define CFG_SYS_NOR_FTIM3	0x0
 
-#define CONFIG_FLASH_SHOW_PROGRESS	45 /* count down from 45/5: 9..1 */
+#define CFG_FLASH_SHOW_PROGRESS	45 /* count down from 45/5: 9..1 */
 
 #define CFG_SYS_FLASH_BANKS_LIST	{CFG_SYS_FLASH_BASE_PHYS}
 
diff --git a/include/configs/T208xQDS.h b/include/configs/T208xQDS.h
index 5244c9d076f0..0d245940dc0e 100644
--- a/include/configs/T208xQDS.h
+++ b/include/configs/T208xQDS.h
@@ -119,7 +119,7 @@
 				FTIM2_NOR_TWP(0x1c))
 #define CFG_SYS_NOR_FTIM3	0x0
 
-#define CONFIG_FLASH_SHOW_PROGRESS	45 /* count down from 45/5: 9..1 */
+#define CFG_FLASH_SHOW_PROGRESS	45 /* count down from 45/5: 9..1 */
 
 #define CFG_SYS_FLASH_BANKS_LIST	{CFG_SYS_FLASH_BASE_PHYS \
 					+ 0x8000000, CFG_SYS_FLASH_BASE_PHYS}
diff --git a/include/configs/T208xRDB.h b/include/configs/T208xRDB.h
index 022d483da763..28c59b4e66f8 100644
--- a/include/configs/T208xRDB.h
+++ b/include/configs/T208xRDB.h
@@ -114,7 +114,7 @@
 				FTIM2_NOR_TWP(0x1c))
 #define CFG_SYS_NOR_FTIM3	0x0
 
-#define CONFIG_FLASH_SHOW_PROGRESS	45 /* count down from 45/5: 9..1 */
+#define CFG_FLASH_SHOW_PROGRESS	45 /* count down from 45/5: 9..1 */
 
 #define CFG_SYS_FLASH_BANKS_LIST	{CFG_SYS_FLASH_BASE_PHYS }
 
diff --git a/include/configs/T4240RDB.h b/include/configs/T4240RDB.h
index 6cf8b75c86c2..640c12d91ab5 100644
--- a/include/configs/T4240RDB.h
+++ b/include/configs/T4240RDB.h
@@ -184,7 +184,7 @@
 				FTIM2_NOR_TWP(0x1c))
 #define CFG_SYS_NOR_FTIM3	0x0
 
-#define CONFIG_FLASH_SHOW_PROGRESS	45 /* count down from 45/5: 9..1 */
+#define CFG_FLASH_SHOW_PROGRESS	45 /* count down from 45/5: 9..1 */
 
 #define CFG_SYS_FLASH_BANKS_LIST	{CFG_SYS_FLASH_BASE_PHYS \
 					+ 0x8000000, CFG_SYS_FLASH_BASE_PHYS}
diff --git a/include/configs/blanche.h b/include/configs/blanche.h
index cb28ae28dd3e..dc74ed3e79d6 100644
--- a/include/configs/blanche.h
+++ b/include/configs/blanche.h
@@ -25,7 +25,7 @@
 #if !defined(CONFIG_MTD_NOR_FLASH)
 #define CONFIG_SH_QSPI_BASE	0xE6B10000
 #else
-#define CONFIG_FLASH_SHOW_PROGRESS	45
+#define CFG_FLASH_SHOW_PROGRESS	45
 #define CFG_SYS_FLASH_BASE		0x00000000
 #define CFG_SYS_FLASH_SIZE		0x04000000	/* 64 MB */
 #define CFG_SYS_FLASH_BANKS_LIST	{ (CFG_SYS_FLASH_BASE) }
diff --git a/include/configs/draak.h b/include/configs/draak.h
index 8140bc469c52..03972d44789b 100644
--- a/include/configs/draak.h
+++ b/include/configs/draak.h
@@ -13,7 +13,7 @@
 
 /* Environment in eMMC, at the end of 2nd "boot sector" */
 
-#define CONFIG_FLASH_SHOW_PROGRESS	45
+#define CFG_FLASH_SHOW_PROGRESS	45
 #define CFG_SYS_FLASH_BANKS_LIST	{ 0x08000000 }
 #define CFG_SYS_WRITE_SWAPPED_DATA
 
diff --git a/include/configs/eb_cpu5282.h b/include/configs/eb_cpu5282.h
index 21eab9b3a479..5ef51c94dab8 100644
--- a/include/configs/eb_cpu5282.h
+++ b/include/configs/eb_cpu5282.h
@@ -84,7 +84,7 @@
 /*-----------------------------------------------------------------------
  * FLASH organization
  */
-#define CONFIG_FLASH_SHOW_PROGRESS	45
+#define CFG_FLASH_SHOW_PROGRESS	45
 
 #define CFG_SYS_FLASH_BASE		CFG_SYS_CS0_BASE
 #define	CFG_SYS_INT_FLASH_BASE	0xF0000000
diff --git a/include/configs/ebisu.h b/include/configs/ebisu.h
index d1882a9646be..ced71856b434 100644
--- a/include/configs/ebisu.h
+++ b/include/configs/ebisu.h
@@ -15,7 +15,7 @@
 
 /* Environment in eMMC, at the end of 2nd "boot sector" */
 
-#define CONFIG_FLASH_SHOW_PROGRESS	45
+#define CFG_FLASH_SHOW_PROGRESS	45
 #define CFG_SYS_FLASH_BANKS_LIST	{ 0x08000000 }
 #define CFG_SYS_WRITE_SWAPPED_DATA
 
diff --git a/include/configs/km/pg-wcom-ls102xa.h b/include/configs/km/pg-wcom-ls102xa.h
index a67301b9ecd6..64fb706a1ce6 100644
--- a/include/configs/km/pg-wcom-ls102xa.h
+++ b/include/configs/km/pg-wcom-ls102xa.h
@@ -61,7 +61,7 @@
 					FTIM2_NOR_TWP(0xb))
 #define CFG_SYS_NOR_FTIM3		0
 
-#define CONFIG_FLASH_SHOW_PROGRESS	45	/* count down from 45/5: 9..1 */
+#define CFG_FLASH_SHOW_PROGRESS	45	/* count down from 45/5: 9..1 */
 
 #define CFG_SYS_FLASH_BANKS_LIST	{ CFG_SYS_FLASH_BASE_PHYS }
 
diff --git a/include/configs/ls1021aqds.h b/include/configs/ls1021aqds.h
index 3bfb014adf11..69f9bacad97c 100644
--- a/include/configs/ls1021aqds.h
+++ b/include/configs/ls1021aqds.h
@@ -60,7 +60,7 @@
 					FTIM2_NOR_TWP(0x1c))
 #define CFG_SYS_NOR_FTIM3		0
 
-#define CONFIG_FLASH_SHOW_PROGRESS	45
+#define CFG_FLASH_SHOW_PROGRESS	45
 #define CFG_SYS_WRITE_SWAPPED_DATA
 
 #define CFG_SYS_FLASH_BANKS_LIST	{CFG_SYS_FLASH_BASE_PHYS, \
diff --git a/include/configs/ls1021atwr.h b/include/configs/ls1021atwr.h
index 8a36620bf3ab..da1e409e5c77 100644
--- a/include/configs/ls1021atwr.h
+++ b/include/configs/ls1021atwr.h
@@ -92,7 +92,7 @@
 					FTIM2_NOR_TWPH(0x0e))
 #define CFG_SYS_NOR_FTIM3		0
 
-#define CONFIG_FLASH_SHOW_PROGRESS	45	/* count down from 45/5: 9..1 */
+#define CFG_FLASH_SHOW_PROGRESS	45	/* count down from 45/5: 9..1 */
 
 #define CFG_SYS_FLASH_BANKS_LIST	{ CFG_SYS_FLASH_BASE_PHYS }
 
diff --git a/include/configs/ls1043a_common.h b/include/configs/ls1043a_common.h
index e259cf810c0a..c79e113db4e4 100644
--- a/include/configs/ls1043a_common.h
+++ b/include/configs/ls1043a_common.h
@@ -92,7 +92,7 @@
 #define CFG_SYS_FLASH_BASE_PHYS_EARLY	0x00000000
 
 #ifdef CONFIG_MTD_NOR_FLASH
-#define CONFIG_FLASH_SHOW_PROGRESS	45	/* count down from 45/5: 9..1 */
+#define CFG_FLASH_SHOW_PROGRESS	45	/* count down from 45/5: 9..1 */
 #endif
 #endif
 #endif
diff --git a/include/configs/ls1046aqds.h b/include/configs/ls1046aqds.h
index 553ae841caba..e67ded55da6b 100644
--- a/include/configs/ls1046aqds.h
+++ b/include/configs/ls1046aqds.h
@@ -43,7 +43,7 @@
 #define CFG_SYS_FLASH_BASE_PHYS_EARLY	0x00000000
 
 #ifdef CONFIG_MTD_NOR_FLASH
-#define CONFIG_FLASH_SHOW_PROGRESS	45	/* count down from 45/5: 9..1 */
+#define CFG_FLASH_SHOW_PROGRESS	45	/* count down from 45/5: 9..1 */
 #endif
 #endif
 
diff --git a/include/configs/ls1088aqds.h b/include/configs/ls1088aqds.h
index a34a71f649f6..0582a4568dc7 100644
--- a/include/configs/ls1088aqds.h
+++ b/include/configs/ls1088aqds.h
@@ -62,7 +62,7 @@
 #define CFG_SYS_IFC_CCR	0x01000000
 
 #ifndef SYS_NO_FLASH
-#define CONFIG_FLASH_SHOW_PROGRESS	45 /* count down from 45/5: 9..1 */
+#define CFG_FLASH_SHOW_PROGRESS	45 /* count down from 45/5: 9..1 */
 
 #define CFG_SYS_FLASH_BANKS_LIST	{ CFG_SYS_FLASH_BASE,\
 					 CFG_SYS_FLASH_BASE + 0x40000000}
diff --git a/include/configs/ls1088ardb.h b/include/configs/ls1088ardb.h
index bd543a37e879..ee796facc06c 100644
--- a/include/configs/ls1088ardb.h
+++ b/include/configs/ls1088ardb.h
@@ -47,7 +47,7 @@
 #define CFG_SYS_IFC_CCR	0x01000000
 
 #ifndef SYS_NO_FLASH
-#define CONFIG_FLASH_SHOW_PROGRESS	45 /* count down from 45/5: 9..1 */
+#define CFG_FLASH_SHOW_PROGRESS	45 /* count down from 45/5: 9..1 */
 
 #define CFG_SYS_FLASH_BANKS_LIST	{ CFG_SYS_FLASH_BASE }
 #endif
diff --git a/include/configs/ls2080aqds.h b/include/configs/ls2080aqds.h
index 12b5af1b4f2f..d029d841d51e 100644
--- a/include/configs/ls2080aqds.h
+++ b/include/configs/ls2080aqds.h
@@ -64,7 +64,7 @@
 #define CFG_SYS_IFC_CCR	0x01000000
 
 #ifdef CONFIG_MTD_NOR_FLASH
-#define CONFIG_FLASH_SHOW_PROGRESS	45 /* count down from 45/5: 9..1 */
+#define CFG_FLASH_SHOW_PROGRESS	45 /* count down from 45/5: 9..1 */
 
 #define CFG_SYS_FLASH_BANKS_LIST	{ CFG_SYS_FLASH_BASE,\
 					 CFG_SYS_FLASH_BASE + 0x40000000}
diff --git a/include/configs/ls2080ardb.h b/include/configs/ls2080ardb.h
index 1259df8f3a9a..73477978be46 100644
--- a/include/configs/ls2080ardb.h
+++ b/include/configs/ls2080ardb.h
@@ -61,7 +61,7 @@
 #define CFG_SYS_IFC_CCR	0x01000000
 
 #ifdef CONFIG_MTD_NOR_FLASH
-#define CONFIG_FLASH_SHOW_PROGRESS	45 /* count down from 45/5: 9..1 */
+#define CFG_FLASH_SHOW_PROGRESS	45 /* count down from 45/5: 9..1 */
 
 #define CFG_SYS_FLASH_BANKS_LIST	{ CFG_SYS_FLASH_BASE,\
 					 CFG_SYS_FLASH_BASE + 0x40000000}
diff --git a/include/configs/p1_p2_rdb_pc.h b/include/configs/p1_p2_rdb_pc.h
index de7c0d61c05f..93909eda55dd 100644
--- a/include/configs/p1_p2_rdb_pc.h
+++ b/include/configs/p1_p2_rdb_pc.h
@@ -199,7 +199,7 @@
 #define CFG_FLASH_OR_PRELIM	0xfc000ff7
 
 #define CFG_SYS_FLASH_BANKS_LIST	{CFG_SYS_FLASH_BASE_PHYS}
-#define CONFIG_FLASH_SHOW_PROGRESS	45	/* count down from 45/5: 9..1 */
+#define CFG_FLASH_SHOW_PROGRESS	45	/* count down from 45/5: 9..1 */
 
 /* Nand Flash */
 #ifdef CONFIG_NAND_FSL_ELBC
diff --git a/include/configs/salvator-x.h b/include/configs/salvator-x.h
index 2e422cd241e9..cb48538e62b4 100644
--- a/include/configs/salvator-x.h
+++ b/include/configs/salvator-x.h
@@ -13,7 +13,7 @@
 
 /* Environment in eMMC, at the end of 2nd "boot sector" */
 
-#define CONFIG_FLASH_SHOW_PROGRESS	45
+#define CFG_FLASH_SHOW_PROGRESS	45
 #define CFG_SYS_FLASH_BANKS_LIST	{ 0x08000000 }
 #define CFG_SYS_WRITE_SWAPPED_DATA
 
diff --git a/include/configs/ulcb.h b/include/configs/ulcb.h
index ab199bc726a6..aadcb30d0432 100644
--- a/include/configs/ulcb.h
+++ b/include/configs/ulcb.h
@@ -13,7 +13,7 @@
 
 /* Environment in eMMC, at the end of 2nd "boot sector" */
 
-#define CONFIG_FLASH_SHOW_PROGRESS	45
+#define CFG_FLASH_SHOW_PROGRESS	45
 #define CFG_SYS_FLASH_BANKS_LIST	{ 0x08000000 }
 #define CFG_SYS_WRITE_SWAPPED_DATA
 
diff --git a/include/configs/zynq-common.h b/include/configs/zynq-common.h
index 7f739d9ada0e..1edd49a784d4 100644
--- a/include/configs/zynq-common.h
+++ b/include/configs/zynq-common.h
@@ -36,7 +36,7 @@
 
 /* NOR */
 #ifdef CONFIG_MTD_NOR_FLASH
-# define CONFIG_FLASH_SHOW_PROGRESS	10
+# define CFG_FLASH_SHOW_PROGRESS	10
 #endif
 
 #ifdef CONFIG_USB_EHCI_ZYNQ
diff --git a/scripts/config_whitelist.txt b/scripts/config_whitelist.txt
index 89f47538d4c7..c510c45d8795 100644
--- a/scripts/config_whitelist.txt
+++ b/scripts/config_whitelist.txt
@@ -31,7 +31,7 @@ CFG_FEC_MXC_PHYADDR
 CFG_FLASH_BR_PRELIM
 CFG_FLASH_OR_PRELIM
 CFG_FLASH_SECTOR_SIZE
-CONFIG_FLASH_SHOW_PROGRESS
+CFG_FLASH_SHOW_PROGRESS
 CONFIG_FLASH_SPANSION_S29WS_N
 CONFIG_FLASH_VERIFY
 CONFIG_FM_PLAT_CLK_DIV
diff --git a/drivers/mtd/cfi_flash.c b/drivers/mtd/cfi_flash.c
index c1cdd2cbc3e2..75765d76ea29 100644
--- a/drivers/mtd/cfi_flash.c
+++ b/drivers/mtd/cfi_flash.c
@@ -1292,7 +1292,7 @@ void flash_print_info(flash_info_t *info)
  * effect updates to digit and dots.  Repeated code is nasty too, so
  * we define it once here.
  */
-#ifdef CONFIG_FLASH_SHOW_PROGRESS
+#ifdef CFG_FLASH_SHOW_PROGRESS
 #define FLASH_SHOW_PROGRESS(scale, dots, digit, dots_sub) \
 	if (flash_verbose) { \
 		dots -= dots_sub; \
@@ -1325,17 +1325,17 @@ int write_buff(flash_info_t *info, uchar *src, ulong addr, ulong cnt)
 #ifdef CONFIG_SYS_FLASH_USE_BUFFER_WRITE
 	int buffered_size;
 #endif
-#ifdef CONFIG_FLASH_SHOW_PROGRESS
-	int digit = CONFIG_FLASH_SHOW_PROGRESS;
+#ifdef CFG_FLASH_SHOW_PROGRESS
+	int digit = CFG_FLASH_SHOW_PROGRESS;
 	int scale = 0;
 	int dots  = 0;
 
 	/*
 	 * Suppress if there are fewer than CONFIG_FLASH_SHOW_PROGRESS writes.
 	 */
-	if (cnt >= CONFIG_FLASH_SHOW_PROGRESS) {
-		scale = (int)((cnt + CONFIG_FLASH_SHOW_PROGRESS - 1) /
-			CONFIG_FLASH_SHOW_PROGRESS);
+	if (cnt >= CFG_FLASH_SHOW_PROGRESS) {
+		scale = (int)((cnt + CFG_FLASH_SHOW_PROGRESS - 1) /
+			CFG_FLASH_SHOW_PROGRESS);
 	}
 #endif
 
@@ -1325,17 +1325,17 @@ int write_buff(flash_info_t *info, uchar *src, ulong addr, ulong cnt)
 
 	/*
-	 * Suppress if there are fewer than CONFIG_FLASH_SHOW_PROGRESS writes.
+	 * Suppress if there are fewer than CFG_FLASH_SHOW_PROGRESS writes.
 	 */
-- 
2.25.1



More information about the U-Boot mailing list